@@ -49,27 +49,76 @@ struct _AsMetadataClass
 };
 
 /**
- * AsParserMode:
- * @AS_PARSER_MODE_UPSTREAM:	Parse Appstream upstream metadata
- * @AS_PARSER_MODE_DISTRO:	Parse Appstream distribution metadata
+ * AsFormatStyle:
+ * @AS_FORMAT_STYLE_METAINFO:	Parse AppStream upstream metadata (metainfo files)
+ * @AS_FORMAT_STYLE_COLLECTION:	Parse AppStream metadata collections (shipped by software distributors)
  *
- * There are a few differences between Appstream's upstream metadata
- * and the distribution metadata.
- * The parser mode indicates which style we should process.
- * Usually you don't want to change this.
+ * There are a few differences between AppStream's metainfo files (shipped by upstream projects)
+ * and the collection metadata (shipped by distributors).
+ * The data source kind indicates which style we should process.
+ * Usually you do not want to set this explicitly.
  **/
 typedef enum {
-	AS_PARSER_MODE_UPSTREAM,
-	AS_PARSER_MODE_DISTRO,
+	AS_FORMAT_STYLE_UNKNOWN,
+	AS_FORMAT_STYLE_METAINFO,
+	AS_FORMAT_STYLE_COLLECTION,
 	/*< private >*/
-	AS_PARSER_MODE_LAST
-} AsParserMode;
+	AS_FORMAT_STYLE_LAST
+} AsFormatStyle;
+
+/**
+ * AsFormatKind:
+ * @AS_FORMAT_KIND_UNKNOWN:		Unknown metadata format.
+ * @AS_FORMAT_KIND_XML:			AppStream XML metadata.
+ * @AS_FORMAT_KIND_YAML:		AppStream YAML (DEP-11) metadata.
+ * @AS_FORMAT_KIND_DESKTOP_ENTRY:	XDG Desktop Entry data.
+ *
+ * Format of the AppStream metadata.
+ **/
+typedef enum {
+	AS_FORMAT_KIND_UNKNOWN,
+	AS_FORMAT_KIND_XML,
+	AS_FORMAT_KIND_YAML,
+	AS_FORMAT_KIND_DESKTOP_ENTRY,
+	/*< private >*/
+	AS_FORMAT_KIND_LAST
+} AsFormatKind;
+
+const gchar		*as_format_kind_to_string (AsFormatKind kind);
+AsFormatKind		 as_format_kind_from_string (const gchar *kind_str);
+
+/**
+ * AsFormatVersion:
+ * @AS_FORMAT_VERSION_V0_6:	0.6
+ * @AS_FORMAT_VERSION_V0_7:	0.7
+ * @AS_FORMAT_VERSION_V0_8:	0.8
+ * @AS_FORMAT_VERSION_V0_9:	0.9
+ * @AS_FORMAT_VERSION_V0_10:	0.10
+ * @AS_FORMAT_VERSION_V0_11:	0.11
+ *
+ * Format version / API level of the AppStream metadata.
+ **/
+typedef enum {
+	AS_FORMAT_VERSION_V0_6,
+	AS_FORMAT_VERSION_V0_7,
+	AS_FORMAT_VERSION_V0_8,
+	AS_FORMAT_VERSION_V0_9,
+	AS_FORMAT_VERSION_V0_10,
+	AS_FORMAT_VERSION_V0_11,
+	/*< private >*/
+	AS_FORMAT_VERSION_LAST
+} AsFormatVersion;
+
+const gchar		*as_format_version_to_string (AsFormatVersion version);
+AsFormatVersion		 as_format_version_from_string (const gchar *version_str);
+
+#define AS_CURRENT_FORMAT_VERSION AS_FORMAT_VERSION_V0_11
 
 /**
  * AsMetadataError:
  * @AS_METADATA_ERROR_FAILED:			Generic failure.
  * @AS_METADATA_ERROR_PARSE:			Unable to parse the metadata file.
- * @AS_METADATA_ERROR_UNEXPECTED_FORMAT_KIND:	Expected upstream metadata but got distro metadata, or vice versa.
+ * @AS_METADATA_ERROR_FORMAT_UNEXPECTED:	Expected collection metadata but got metainfo metadata, or vice versa.
  * @AS_METADATA_ERROR_NO_COMPONENT:		We expected a component in the pool, but couldn't find one.
  *
  * A metadata processing error.
@@ -77,7 +126,7 @@ typedef enum {
 typedef enum {
 	AS_METADATA_ERROR_FAILED,
 	AS_METADATA_ERROR_PARSE,
-	AS_METADATA_ERROR_UNEXPECTED_FORMAT_KIND,
+	AS_METADATA_ERROR_FORMAT_UNEXPECTED,
 	AS_METADATA_ERROR_NO_COMPONENT,
 	/*< private >*/
 	AS_METADATA_ERROR_LAST
@@ -89,14 +138,18 @@ AsMetadata		*as_metadata_new (void);
 GQuark			as_metadata_error_quark (void);
 
 void			as_metadata_parse_file (AsMetadata *metad,
-							GFile *file,
-							GError **error);
+						GFile *file,
+						AsFormatKind format,
+						GError **error);
 
-void			as_metadata_parse_xml (AsMetadata *metad,
-							const gchar *data,
-							GError **error);
-void			as_metadata_parse_yaml (AsMetadata *metad,
+void			as_metadata_parse (AsMetadata *metad,
+						const gchar *data,
+						AsFormatKind format,
+						GError **error);
+
+void			as_metadata_parse_desktop_data (AsMetadata *metad,
 							const gchar *data,
+							const gchar *cid,
 							GError **error);
 
 AsComponent		*as_metadata_get_component (AsMetadata *metad);
@@ -106,20 +159,30 @@ void			as_metadata_clear_components (AsMetadata *metad);
 void			as_metadata_add_component (AsMetadata *metad,
 							AsComponent *cpt);
 
-gchar			*as_metadata_component_to_upstream_xml (AsMetadata *metad);
-void			as_metadata_save_upstream_xml (AsMetadata *metad,
-							const gchar *fname,
-							GError **error);
-gchar			*as_metadata_components_to_distro_xml (AsMetadata *metad);
-void			as_metadata_save_distro_xml (AsMetadata *metad,
+gchar			*as_metadata_component_to_metainfo (AsMetadata *metad,
+								AsFormatKind format,
+								GError **error);
+void			as_metadata_save_metainfo (AsMetadata *metad,
 							const gchar *fname,
+							AsFormatKind format,
 							GError **error);
 
-gchar			*as_metadata_components_to_distro_yaml (AsMetadata *metad);
-void			as_metadata_save_distro_yaml (AsMetadata *metad,
+gchar			*as_metadata_components_to_collection (AsMetadata *metad,
+								AsFormatKind format,
+								GError **error);
+void			as_metadata_save_collection (AsMetadata *metad,
 							const gchar *fname,
+							AsFormatKind format,
 							GError **error);
 
+AsFormatVersion		as_metadata_get_format_version (AsMetadata *metad);
+void			as_metadata_set_format_version (AsMetadata *metad,
+							AsFormatVersion version);
+
+AsFormatStyle		as_metadata_get_format_style (AsMetadata *metad);
+void			as_metadata_set_format_style (AsMetadata *metad,
+							AsFormatStyle mode);
+
 void			as_metadata_set_locale (AsMetadata *metad,
 							const gchar *locale);
 const gchar		*as_metadata_get_locale (AsMetadata *metad);
@@ -136,10 +199,6 @@ gboolean		as_metadata_get_write_header (AsMetadata *metad);
 void			as_metadata_set_write_header (AsMetadata *metad,
 								gboolean wheader);
 
-void			as_metadata_set_parser_mode (AsMetadata *metad,
-							AsParserMode mode);
-AsParserMode		as_metadata_get_parser_mode (AsMetadata *metad);
-
 const gchar		*as_metadata_get_architecture (AsMetadata *metad);
 void			as_metadata_set_architecture (AsMetadata *metad,
 							const gchar *arch);
